//////////////////////////////////////////////////Display declaration, Variables
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128 // OLED display width, in pixels
#define SCREEN_HEIGHT 64 // OLED display height, in pixels

// Declaration for an SSD1306 display connected to I2C (SDA, SCL pins)
#define OLED_RESET -1 // Reset pin # (or -1 if sharing Arduino reset pin)
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

const int sda = A4, scl = A5;

const int introPIN = A0;
const int playerOnePIN = A1;
const int playerTwoPIN = A2;
const int winnerPIN = A3;

const int LED = 13;
int ledON = 0, ledOFF = 0;

int playerTurn;
bool textColor;
//////////////////////////////////////////////////Void Setup
void setup() {
  Serial.begin(9600);
  if(!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { // Address 0x3D for 128x64
    Serial.println(F("SSD1306 allocation failed"));
    for(;;); // Don't proceed, loop forever
  }
  display.clearDisplay();
  
  pinMode(introPIN, INPUT);
  pinMode(playerOnePIN, INPUT);
  pinMode(playerTwoPIN, INPUT);
  pinMode(winnerPIN, INPUT);
  pinMode(LED, OUTPUT);
}

//////////////////////////////////////////////////Void Loop
void loop() {
  display.clearDisplay();
  if(digitalRead(introPIN)){
    menu();
  }  
  else if(digitalRead(winnerPIN)){
    if(digitalRead(playerOnePIN)) winnerIs(1);
    if(digitalRead(playerTwoPIN)) winnerIs(2);
  }
  else{
    if(digitalRead(playerOnePIN)) playerTurn = 1;
    if(digitalRead(playerTwoPIN)) playerTurn = 2;
    whosTurn(playerTurn);
  }
  
  led();
}

//////////////////////////////////////////////////Functions
void whosTurn(int player){
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  
  display.setCursor(0,0);             
  display.println(F("Player "));

  display.setCursor(85,0);
  display.println(player);

  display.setCursor(60,50);             
  display.println(F("turn"));
  player--;
  
  if(!player){
    display.setCursor(30,25);             
    display.println(F("(RED)"));
  }
  if(player){
    display.setCursor(15,25);             
    display.println(F("(YELLOW)"));
  }
  
  display.display();
}

void menu(){
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);

  display.setCursor(0,15);
  display.println(F("TIC"));
  display.setCursor(46,20);
  display.println(F("TAC"));
  display.setCursor(92,25);
  display.println(F("TOE"));

  display.setTextSize(1);
  display.setTextColor(SSD1306_WHITE);
  
  display.setCursor(0,55);
  display.println(F("-- by Filip Ondrej --"));
  
  display.display();
}

void winnerIs(int winner){  
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);

  display.setCursor(28,0);
  display.println(F("Winner"));

  display.setCursor(5,20);
  display.println(F("player is:"));

  if(!textColor){
    display.setTextColor(SSD1306_WHITE);
    textColor = 1;
  }
  else if(textColor){
    display.setTextColor(SSD1306_BLACK, SSD1306_WHITE);
    textColor = 0;
  }

  winner--;
  if(!winner){
    display.setCursor(10,48);
    display.println(F(" RED (1) "));    
  }
  if(winner){
    display.setCursor(0,48);
    display.println(F("YELLOW (2)"));
  }
  
  display.display();
  delay(80);
}

void led(){
  if(ledON != 0){
    digitalWrite(LED, HIGH);
    ledON--;
  }
  else if(!ledON && ledOFF != 0){
    digitalWrite(LED, LOW);
    ledOFF--;
  }
  else if(!ledON && !ledOFF){
    ledON = random(2, 50);
    ledOFF = random(1, 20);
  }
}
